@@ -1,3 +1,16 @@
+/**
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
+ *
+ * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ *
+ * @author Viktor Pracht <viktor.pracht@open-xchange.com>
+ */
+ 
 define('com.spamexperts/settings/register', [
     'io.ox/core/extensions',
     'io.ox/core/http',
@@ -5,12 +18,12 @@ define('com.spamexperts/settings/register', [
 ], function (ext, http, settings) {
     'use strict';
 
-    ext.point('io.ox/settings/pane').extend({
+    ext.point('io.ox/settings/pane/main/io.ox/mail').extend({
         id: 'com.spamexperts',
         title: _.noI18n(settings.get('name')),
         ref: 'com.spamexperts',
         loadSettingPane: false,
-        after: 'io.ox/mail'
+        index: 'last'
     });
     
     ext.point('com.spamexperts/settings/detail').extend({
